@@ -91,12 +91,24 @@ class BaseClient(object):
             params['timeout'] = conn.timeout
         return params
 
+    def _gunzip_body(self, body):
+        sio = StringIO.StringIO(body)
+        gf = gzip.GzipFile(fileobj=sio, mode="rb")
+        return gf.read()
+
+    def _process_body(self, data, gzipped):
+        if gzipped:
+            return self._gunzip_body(data)
+        return data
+
     def _execute_request_raw(self, conn, request):
         try:
             result = conn.getresponse()
         except:
             raise HapiTimeout(None, request, traceback.format_exc())
-        result.body = result.read()
+
+        encoding = [i[1] for i in result.getheaders() if i[0] == 'content-encoding']
+        result.body = self._process_body(result.read(), len(encoding) and encoding[0] == 'gzip')
 
         conn.close()
         if result.status in (404, 410):
@@ -112,14 +124,7 @@ class BaseClient(object):
         result = self._execute_request_raw(conn, request)
         return result.body
 
-    def _digest_result(self, data, gzipped=False):
-
-        if gzipped:
-            sio = StringIO.StringIO(data)
-            gf = gzip.GzipFile(fileobj=sio, mode="rb")
-            gdata = gf.read()
-            data = gdata
-
+    def _digest_result(self, data):
         if data and isinstance(data, basestring):
             try:
                 data = json.loads(data)
@@ -170,9 +175,4 @@ class BaseClient(object):
 
     def _call(self, subpath, params=None, method='GET', data=None, doseq=False, **options):
         result = self._call_raw(subpath, params=params, method=method, data=data, doseq=doseq, **options)
-        gzipped = False
-        encoding = [i[1] for i in result.getheaders() if i[0] == 'content-encoding']
-        if len(encoding) and encoding[0] == 'gzip':
-            gzipped = True
-
-        return self._digest_result(result.body, gzipped)
+        return self._digest_result(result.body)
